@@ -1,10 +1,9 @@
 package AnyEvent::ProcessPool::Worker;
 # ABSTRACT: The task executor code run in the worker process
-$AnyEvent::ProcessPool::Worker::VERSION = '0.06';
-use strict;
-use warnings;
+$AnyEvent::ProcessPool::Worker::VERSION = '0.07';
 use v5.10;
-require AnyEvent::ProcessPool::Task;
+use common::sense;
+use AnyEvent::ProcessPool::Task;
 
 sub run {
   local $| = 1;
@@ -29,7 +28,7 @@ AnyEvent::ProcessPool::Worker - The task executor code run in the worker process
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
